fork of lcd driver

Dependencies:   DmTftLibrary

Fork of dm_main by Display Module

Revision:
5:47192882d9d0
Parent:
4:d58fe9f48040
--- a/main.cpp	Thu Jan 22 03:06:58 2015 +0000
+++ b/main.cpp	Mon Oct 12 08:42:18 2015 +0000
@@ -32,19 +32,19 @@
    use the same pins for USBRX/USBTX and display control. Printing will
    cause the display to not work. Read more about this on the display's notebook
    page. */
-//#define log(...) printf(__VA_ARGS__)
-#define log(...)
+#define log(...) printf(__VA_ARGS__)
+//#define log(...)
 
 /******************************************************************************
  * Local variables
  *****************************************************************************/
 
-//DmTftHX8353C tft;  /* DM_TFT18_101 */
-//DmTftS6D0164 tft;  /* DM_TFT22_102 */
-//DmTftIli9325 tft;  /* DM_TFT28_103 and DM_TFT24_104 */
-//DmTftIli9341 tft;  /* DM_TFT28_105 */
-//DmTftSsd2119 tft;  /* DM_TFT35_107 */
-DmTftRa8875  tft;  /* DM_TFT43_108 and DM_TFT50_111   For DmTftRa8875 driver, The panel resolution should be config in DmTftRa8875::init() function on the DmTftRa8875.cpp file. */
+//DmTftHX8353C tft(D2, D3, D4, D5, D6);  /* DmTftHX8353C(PinName mosi, PinName clk, PinName cs, PinName dc, PinName rst) DM_TFT18_101 */
+//DmTftS6D0164 tft(A4, A3, A5, A2);  /* DmTftS6D0164(PinName wr, PinName cs, PinName dc, PinName rst) DM_TFT22_102 */
+//DmTftIli9325 tft(A4, A3, A5, A2);  /* DmTftIli9325(PinName wr, PinName cs, PinName dc, PinName rst) DM_TFT28_103 and DM_TFT24_104 */
+DmTftIli9341 tft(D10, D9, D11, D12, D13);  /* DmTftIli9341(PinName cs, PinName dc, PinName mosi, PinName miso, PinName clk)  DM_TFT28_105 */
+//DmTftSsd2119 tft(D10, D9, D11, D12, D13);  /* DmTftSsd2119(PinName cs, PinName dc, PinName mosi, PinName miso, PinName clk) DM_TFT35_107 */
+//DmTftRa8875  tft(D10, D9, D11, D12, D13);  /* DmTftRa8875(PinName cs, PinName sel, PinName mosi, PinName miso, PinName clk) DM_TFT43_108 and DM_TFT50_111   For DmTftRa8875 driver, The panel resolution should be config in DmTftRa8875::init() function on the DmTftRa8875.cpp file. */
 
 int bmpWidth, bmpHeight;
 uint8_t bmpImageoffset;